/****************************************************************************
** Meta object code from reading C++ file 'kwalleteditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kwalletmanager-17.12.3/src/manager/kwalleteditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalleteditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWalletEditor_t {
    QByteArrayData data[40];
    char stringdata0[558];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWalletEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWalletEditor_t qt_meta_stringdata_KWalletEditor = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KWalletEditor"
QT_MOC_LITERAL(1, 14, 19), // "enableWalletActions"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 6), // "enable"
QT_MOC_LITERAL(4, 42, 19), // "enableFolderActions"
QT_MOC_LITERAL(5, 62, 26), // "enableContextFolderActions"
QT_MOC_LITERAL(6, 89, 12), // "walletClosed"
QT_MOC_LITERAL(7, 102, 12), // "createFolder"
QT_MOC_LITERAL(8, 115, 12), // "deleteFolder"
QT_MOC_LITERAL(9, 128, 16), // "updateFolderList"
QT_MOC_LITERAL(10, 145, 12), // "checkEntries"
QT_MOC_LITERAL(11, 158, 21), // "entrySelectionChanged"
QT_MOC_LITERAL(12, 180, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 197, 4), // "item"
QT_MOC_LITERAL(14, 202, 15), // "listItemChanged"
QT_MOC_LITERAL(15, 218, 6), // "column"
QT_MOC_LITERAL(16, 225, 24), // "listContextMenuRequested"
QT_MOC_LITERAL(17, 250, 3), // "pos"
QT_MOC_LITERAL(18, 254, 13), // "updateEntries"
QT_MOC_LITERAL(19, 268, 6), // "folder"
QT_MOC_LITERAL(20, 275, 8), // "newEntry"
QT_MOC_LITERAL(21, 284, 11), // "renameEntry"
QT_MOC_LITERAL(22, 296, 11), // "deleteEntry"
QT_MOC_LITERAL(23, 308, 12), // "entryEditted"
QT_MOC_LITERAL(24, 321, 12), // "restoreEntry"
QT_MOC_LITERAL(25, 334, 9), // "saveEntry"
QT_MOC_LITERAL(26, 344, 14), // "changePassword"
QT_MOC_LITERAL(27, 359, 12), // "walletOpened"
QT_MOC_LITERAL(28, 372, 7), // "success"
QT_MOC_LITERAL(29, 380, 20), // "hidePasswordContents"
QT_MOC_LITERAL(30, 401, 20), // "showPasswordContents"
QT_MOC_LITERAL(31, 422, 22), // "showHideMapEditorValue"
QT_MOC_LITERAL(32, 445, 4), // "show"
QT_MOC_LITERAL(33, 450, 9), // "exportXML"
QT_MOC_LITERAL(34, 460, 9), // "importXML"
QT_MOC_LITERAL(35, 470, 12), // "importWallet"
QT_MOC_LITERAL(36, 483, 12), // "copyPassword"
QT_MOC_LITERAL(37, 496, 19), // "onSearchTextChanged"
QT_MOC_LITERAL(38, 516, 20), // "onAlwaysShowContents"
QT_MOC_LITERAL(39, 537, 20) // "onAlwaysHideContents"

    },
    "KWalletEditor\0enableWalletActions\0\0"
    "enable\0enableFolderActions\0"
    "enableContextFolderActions\0walletClosed\0"
    "createFolder\0deleteFolder\0updateFolderList\0"
    "checkEntries\0entrySelectionChanged\0"
    "QTreeWidgetItem*\0item\0listItemChanged\0"
    "column\0listContextMenuRequested\0pos\0"
    "updateEntries\0folder\0newEntry\0renameEntry\0"
    "deleteEntry\0entryEditted\0restoreEntry\0"
    "saveEntry\0changePassword\0walletOpened\0"
    "success\0hidePasswordContents\0"
    "showPasswordContents\0showHideMapEditorValue\0"
    "show\0exportXML\0importXML\0importWallet\0"
    "copyPassword\0onSearchTextChanged\0"
    "onAlwaysShowContents\0onAlwaysHideContents"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWalletEditor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  164,    2, 0x06 /* Public */,
       4,    1,  167,    2, 0x06 /* Public */,
       5,    1,  170,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  173,    2, 0x0a /* Public */,
       7,    0,  174,    2, 0x0a /* Public */,
       8,    0,  175,    2, 0x0a /* Public */,
       9,    1,  176,    2, 0x08 /* Private */,
       9,    0,  179,    2, 0x28 /* Private | MethodCloned */,
      11,    1,  180,    2, 0x08 /* Private */,
      14,    2,  183,    2, 0x08 /* Private */,
      16,    1,  188,    2, 0x08 /* Private */,
      18,    1,  191,    2, 0x08 /* Private */,
      20,    0,  194,    2, 0x08 /* Private */,
      21,    0,  195,    2, 0x08 /* Private */,
      22,    0,  196,    2, 0x08 /* Private */,
      23,    0,  197,    2, 0x08 /* Private */,
      24,    0,  198,    2, 0x08 /* Private */,
      25,    0,  199,    2, 0x08 /* Private */,
      26,    0,  200,    2, 0x08 /* Private */,
      27,    1,  201,    2, 0x08 /* Private */,
      29,    0,  204,    2, 0x08 /* Private */,
      30,    0,  205,    2, 0x08 /* Private */,
      31,    1,  206,    2, 0x08 /* Private */,
      33,    0,  209,    2, 0x08 /* Private */,
      34,    0,  210,    2, 0x08 /* Private */,
      35,    0,  211,    2, 0x08 /* Private */,
      36,    0,  212,    2, 0x08 /* Private */,
      37,    1,  213,    2, 0x08 /* Private */,
      38,    1,  216,    2, 0x08 /* Private */,
      39,    1,  219,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int,    2,   15,
    QMetaType::Void, QMetaType::QPoint,   17,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void KWalletEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KWalletEditor *_t = static_cast<KWalletEditor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->enableWalletActions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->enableFolderActions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->enableContextFolderActions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->walletClosed(); break;
        case 4: _t->createFolder(); break;
        case 5: _t->deleteFolder(); break;
        case 6: _t->updateFolderList((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->updateFolderList(); break;
        case 8: _t->entrySelectionChanged((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 9: _t->listItemChanged((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->listContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 11: _t->updateEntries((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->newEntry(); break;
        case 13: _t->renameEntry(); break;
        case 14: _t->deleteEntry(); break;
        case 15: _t->entryEditted(); break;
        case 16: _t->restoreEntry(); break;
        case 17: _t->saveEntry(); break;
        case 18: _t->changePassword(); break;
        case 19: _t->walletOpened((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->hidePasswordContents(); break;
        case 21: _t->showPasswordContents(); break;
        case 22: _t->showHideMapEditorValue((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->exportXML(); break;
        case 24: _t->importXML(); break;
        case 25: _t->importWallet(); break;
        case 26: _t->copyPassword(); break;
        case 27: _t->onSearchTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->onAlwaysShowContents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->onAlwaysHideContents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KWalletEditor::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletEditor::enableWalletActions)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KWalletEditor::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletEditor::enableFolderActions)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KWalletEditor::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletEditor::enableContextFolderActions)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KWalletEditor::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KWalletEditor.data,
      qt_meta_data_KWalletEditor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KWalletEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWalletEditor.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WalletWidget"))
        return static_cast< Ui::WalletWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int KWalletEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void KWalletEditor::enableWalletActions(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KWalletEditor::enableFolderActions(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KWalletEditor::enableContextFolderActions(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
