#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'walletwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WALLETWIDGET_H
#define UI_WALLETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kiconloader.h>
#include "ksqueezedtextlabel.h"
#include "kwhexview.h"

QT_BEGIN_NAMESPACE

class Ui_WalletWidget
{
public:
    QGridLayout *gridLayout;
    QSplitter *_splitter;
    QFrame *_entryListFrame;
    QWidget *layout3;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *hboxLayout;
    QLabel *_iconTitle;
    QLabel *_entryTitle;
    KSqueezedTextLabel *_entryName;
    QStackedWidget *_entryStack;
    QWidget *page1;
    QWidget *page2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QToolButton *_hideContents;
    QSpacerItem *horizontalSpacer_5;
    QTextEdit *_passwordValue;
    QWidget *page3;
    QWidget *binaryPage;
    QVBoxLayout *verticalLayout;
    QCheckBox *_binaryViewShow;
    KWHexView *_binaryView;
    QSpacerItem *verticalSpacer;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *_showContents;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QPushButton *_undoChanges;
    QPushButton *_saveChanges;

    void setupUi(QWidget *WalletWidget)
    {
        if (WalletWidget->objectName().isEmpty())
            WalletWidget->setObjectName(QStringLiteral("WalletWidget"));
        WalletWidget->resize(482, 407);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(WalletWidget->sizePolicy().hasHeightForWidth());
        WalletWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(WalletWidget);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        _splitter = new QSplitter(WalletWidget);
        _splitter->setObjectName(QStringLiteral("_splitter"));
        sizePolicy.setHeightForWidth(_splitter->sizePolicy().hasHeightForWidth());
        _splitter->setSizePolicy(sizePolicy);
        _splitter->setOrientation(Qt::Horizontal);
        _splitter->setOpaqueResize(true);
        _splitter->setChildrenCollapsible(false);
        _entryListFrame = new QFrame(_splitter);
        _entryListFrame->setObjectName(QStringLiteral("_entryListFrame"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(_entryListFrame->sizePolicy().hasHeightForWidth());
        _entryListFrame->setSizePolicy(sizePolicy1);
        _entryListFrame->setFrameShape(QFrame::NoFrame);
        _entryListFrame->setFrameShadow(QFrame::Plain);
        _splitter->addWidget(_entryListFrame);
        layout3 = new QWidget(_splitter);
        layout3->setObjectName(QStringLiteral("layout3"));
        verticalLayout_4 = new QVBoxLayout(layout3);
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        _iconTitle = new QLabel(layout3);
        _iconTitle->setObjectName(QStringLiteral("_iconTitle"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(_iconTitle->sizePolicy().hasHeightForWidth());
        _iconTitle->setSizePolicy(sizePolicy2);
        _iconTitle->setWordWrap(false);

        hboxLayout->addWidget(_iconTitle);

        _entryTitle = new QLabel(layout3);
        _entryTitle->setObjectName(QStringLiteral("_entryTitle"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(_entryTitle->sizePolicy().hasHeightForWidth());
        _entryTitle->setSizePolicy(sizePolicy3);
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        _entryTitle->setFont(font);
        _entryTitle->setTextFormat(Qt::RichText);
        _entryTitle->setAlignment(Qt::AlignVCenter);
        _entryTitle->setWordWrap(false);

        hboxLayout->addWidget(_entryTitle);


        verticalLayout_4->addLayout(hboxLayout);

        _entryName = new KSqueezedTextLabel(layout3);
        _entryName->setObjectName(QStringLiteral("_entryName"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(_entryName->sizePolicy().hasHeightForWidth());
        _entryName->setSizePolicy(sizePolicy4);
        _entryName->setTextFormat(Qt::PlainText);

        verticalLayout_4->addWidget(_entryName);

        _entryStack = new QStackedWidget(layout3);
        _entryStack->setObjectName(QStringLiteral("_entryStack"));
        QSizePolicy sizePolicy5(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(1);
        sizePolicy5.setHeightForWidth(_entryStack->sizePolicy().hasHeightForWidth());
        _entryStack->setSizePolicy(sizePolicy5);
        page1 = new QWidget();
        page1->setObjectName(QStringLiteral("page1"));
        _entryStack->addWidget(page1);
        page2 = new QWidget();
        page2->setObjectName(QStringLiteral("page2"));
        verticalLayout_3 = new QVBoxLayout(page2);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        _hideContents = new QToolButton(page2);
        _hideContents->setObjectName(QStringLiteral("_hideContents"));
        _hideContents->setPopupMode(QToolButton::DelayedPopup);
        _hideContents->setToolButtonStyle(Qt::ToolButtonTextOnly);
        _hideContents->setArrowType(Qt::DownArrow);

        horizontalLayout_3->addWidget(_hideContents);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);


        verticalLayout_3->addLayout(horizontalLayout_3);

        _passwordValue = new QTextEdit(page2);
        _passwordValue->setObjectName(QStringLiteral("_passwordValue"));
        QFont font1;
        font1.setFamily(QStringLiteral("Monospace"));
        _passwordValue->setFont(font1);
        _passwordValue->setAcceptRichText(false);

        verticalLayout_3->addWidget(_passwordValue);

        _entryStack->addWidget(page2);
        page3 = new QWidget();
        page3->setObjectName(QStringLiteral("page3"));
        _entryStack->addWidget(page3);
        binaryPage = new QWidget();
        binaryPage->setObjectName(QStringLiteral("binaryPage"));
        verticalLayout = new QVBoxLayout(binaryPage);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        _binaryViewShow = new QCheckBox(binaryPage);
        _binaryViewShow->setObjectName(QStringLiteral("_binaryViewShow"));
        _binaryViewShow->setChecked(true);

        verticalLayout->addWidget(_binaryViewShow);

        _binaryView = new KWHexView(binaryPage);
        _binaryView->setObjectName(QStringLiteral("_binaryView"));
        QSizePolicy sizePolicy6(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(1);
        sizePolicy6.setHeightForWidth(_binaryView->sizePolicy().hasHeightForWidth());
        _binaryView->setSizePolicy(sizePolicy6);
        _binaryView->setReadOnly(true);

        verticalLayout->addWidget(_binaryView);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        _entryStack->addWidget(binaryPage);
        page_2 = new QWidget();
        page_2->setObjectName(QStringLiteral("page_2"));
        verticalLayout_2 = new QVBoxLayout(page_2);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        _showContents = new QToolButton(page_2);
        _showContents->setObjectName(QStringLiteral("_showContents"));
        _showContents->setToolButtonStyle(Qt::ToolButtonFollowStyle);
        _showContents->setArrowType(Qt::NoArrow);

        horizontalLayout_2->addWidget(_showContents);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_3);

        _entryStack->addWidget(page_2);

        verticalLayout_4->addWidget(_entryStack);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        _undoChanges = new QPushButton(layout3);
        _undoChanges->setObjectName(QStringLiteral("_undoChanges"));
        _undoChanges->setEnabled(false);

        horizontalLayout_4->addWidget(_undoChanges);

        _saveChanges = new QPushButton(layout3);
        _saveChanges->setObjectName(QStringLiteral("_saveChanges"));
        _saveChanges->setEnabled(false);

        horizontalLayout_4->addWidget(_saveChanges);


        verticalLayout_4->addLayout(horizontalLayout_4);

        _splitter->addWidget(layout3);

        gridLayout->addWidget(_splitter, 0, 0, 1, 1);


        retranslateUi(WalletWidget);
        QObject::connect(_binaryViewShow, SIGNAL(toggled(bool)), _binaryView, SLOT(setVisible(bool)));

        _entryStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WalletWidget);
    } // setupUi

    void retranslateUi(QWidget *WalletWidget)
    {
        _iconTitle->setText(QString());
        _entryTitle->setText(QString());
        _hideContents->setText(tr2i18n("Hide &Contents", Q_NULLPTR));
        _binaryViewShow->setText(tr2i18n("Show &Contents", Q_NULLPTR));
        _showContents->setText(tr2i18n("Show &Contents", Q_NULLPTR));
        _undoChanges->setText(tr2i18n("&Undo", Q_NULLPTR));
        _saveChanges->setText(tr2i18n("&Save", Q_NULLPTR));
        Q_UNUSED(WalletWidget);
    } // retranslateUi

};

namespace Ui {
    class WalletWidget: public Ui_WalletWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WALLETWIDGET_H

