#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'walletconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WALLETCONFIGWIDGET_H
#define UI_WALLETCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_WalletConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget2;
    QWidget *tab1;
    QVBoxLayout *vboxLayout;
    QCheckBox *_enabled;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QCheckBox *_closeIdle;
    QSpinBox *_idleTime;
    QSpacerItem *spacerItem;
    QCheckBox *_screensaverLock;
    QCheckBox *_autoclose;
    QGroupBox *groupBox4;
    QGridLayout *gridLayout;
    QLabel *textLabel1_2;
    QSpacerItem *spacerItem1;
    QComboBox *_defaultWallet;
    QPushButton *_newWallet;
    QCheckBox *_localWalletSelected;
    QComboBox *_localWallet;
    QPushButton *_newLocalWallet;
    QGroupBox *groupBox3;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *_launchManager;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QCheckBox *_autocloseManager;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;
    QWidget *tab2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *_openPrompt;
    QTreeWidget *_accessList;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacerItem4;
    QPushButton *_launch;

    void setupUi(QWidget *WalletConfigWidget)
    {
        if (WalletConfigWidget->objectName().isEmpty())
            WalletConfigWidget->setObjectName(QStringLiteral("WalletConfigWidget"));
        verticalLayout = new QVBoxLayout(WalletConfigWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        tabWidget2 = new QTabWidget(WalletConfigWidget);
        tabWidget2->setObjectName(QStringLiteral("tabWidget2"));
        tab1 = new QWidget();
        tab1->setObjectName(QStringLiteral("tab1"));
        vboxLayout = new QVBoxLayout(tab1);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        _enabled = new QCheckBox(tab1);
        _enabled->setObjectName(QStringLiteral("_enabled"));
        _enabled->setChecked(true);

        vboxLayout->addWidget(_enabled);

        groupBox2 = new QGroupBox(tab1);
        groupBox2->setObjectName(QStringLiteral("groupBox2"));
        vboxLayout1 = new QVBoxLayout(groupBox2);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        _closeIdle = new QCheckBox(groupBox2);
        _closeIdle->setObjectName(QStringLiteral("_closeIdle"));

        hboxLayout->addWidget(_closeIdle);

        _idleTime = new QSpinBox(groupBox2);
        _idleTime->setObjectName(QStringLiteral("_idleTime"));
        _idleTime->setEnabled(false);
        _idleTime->setMinimum(1);
        _idleTime->setMaximum(999);
        _idleTime->setSingleStep(5);
        _idleTime->setValue(10);

        hboxLayout->addWidget(_idleTime);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout);

        _screensaverLock = new QCheckBox(groupBox2);
        _screensaverLock->setObjectName(QStringLiteral("_screensaverLock"));

        vboxLayout1->addWidget(_screensaverLock);

        _autoclose = new QCheckBox(groupBox2);
        _autoclose->setObjectName(QStringLiteral("_autoclose"));

        vboxLayout1->addWidget(_autoclose);


        vboxLayout->addWidget(groupBox2);

        groupBox4 = new QGroupBox(tab1);
        groupBox4->setObjectName(QStringLiteral("groupBox4"));
        gridLayout = new QGridLayout(groupBox4);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        textLabel1_2 = new QLabel(groupBox4);
        textLabel1_2->setObjectName(QStringLiteral("textLabel1_2"));

        gridLayout->addWidget(textLabel1_2, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 1, 2, 1);

        _defaultWallet = new QComboBox(groupBox4);
        _defaultWallet->setObjectName(QStringLiteral("_defaultWallet"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_defaultWallet->sizePolicy().hasHeightForWidth());
        _defaultWallet->setSizePolicy(sizePolicy);

        gridLayout->addWidget(_defaultWallet, 0, 2, 1, 1);

        _newWallet = new QPushButton(groupBox4);
        _newWallet->setObjectName(QStringLiteral("_newWallet"));

        gridLayout->addWidget(_newWallet, 0, 3, 1, 1);

        _localWalletSelected = new QCheckBox(groupBox4);
        _localWalletSelected->setObjectName(QStringLiteral("_localWalletSelected"));

        gridLayout->addWidget(_localWalletSelected, 1, 0, 1, 1);

        _localWallet = new QComboBox(groupBox4);
        _localWallet->setObjectName(QStringLiteral("_localWallet"));
        _localWallet->setEnabled(false);
        sizePolicy.setHeightForWidth(_localWallet->sizePolicy().hasHeightForWidth());
        _localWallet->setSizePolicy(sizePolicy);

        gridLayout->addWidget(_localWallet, 1, 2, 1, 1);

        _newLocalWallet = new QPushButton(groupBox4);
        _newLocalWallet->setObjectName(QStringLiteral("_newLocalWallet"));
        _newLocalWallet->setEnabled(false);

        gridLayout->addWidget(_newLocalWallet, 1, 3, 1, 1);


        vboxLayout->addWidget(groupBox4);

        groupBox3 = new QGroupBox(tab1);
        groupBox3->setObjectName(QStringLiteral("groupBox3"));
        verticalLayout_3 = new QVBoxLayout(groupBox3);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        _launchManager = new QCheckBox(groupBox3);
        _launchManager->setObjectName(QStringLiteral("_launchManager"));
        _launchManager->setChecked(true);

        verticalLayout_3->addWidget(_launchManager);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        _autocloseManager = new QCheckBox(groupBox3);
        _autocloseManager->setObjectName(QStringLiteral("_autocloseManager"));

        horizontalLayout_2->addWidget(_autocloseManager);


        verticalLayout_3->addLayout(horizontalLayout_2);

        spacerItem2 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        verticalLayout_3->addItem(spacerItem2);


        vboxLayout->addWidget(groupBox3);

        spacerItem3 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem3);

        tabWidget2->addTab(tab1, QString());
        tab2 = new QWidget();
        tab2->setObjectName(QStringLiteral("tab2"));
        verticalLayout_2 = new QVBoxLayout(tab2);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        _openPrompt = new QCheckBox(tab2);
        _openPrompt->setObjectName(QStringLiteral("_openPrompt"));
        _openPrompt->setChecked(true);

        verticalLayout_2->addWidget(_openPrompt);

        _accessList = new QTreeWidget(tab2);
        _accessList->setObjectName(QStringLiteral("_accessList"));
        _accessList->setRootIsDecorated(true);

        verticalLayout_2->addWidget(_accessList);

        tabWidget2->addTab(tab2, QString());

        verticalLayout->addWidget(tabWidget2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        spacerItem4 = new QSpacerItem(20, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacerItem4);

        _launch = new QPushButton(WalletConfigWidget);
        _launch->setObjectName(QStringLiteral("_launch"));

        horizontalLayout->addWidget(_launch);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(WalletConfigWidget);
        QObject::connect(_localWalletSelected, SIGNAL(toggled(bool)), _newLocalWallet, SLOT(setEnabled(bool)));
        QObject::connect(_localWalletSelected, SIGNAL(toggled(bool)), _localWallet, SLOT(setEnabled(bool)));
        QObject::connect(_closeIdle, SIGNAL(toggled(bool)), _idleTime, SLOT(setEnabled(bool)));
        QObject::connect(_enabled, SIGNAL(toggled(bool)), groupBox2, SLOT(setEnabled(bool)));
        QObject::connect(_enabled, SIGNAL(toggled(bool)), groupBox4, SLOT(setEnabled(bool)));
        QObject::connect(_enabled, SIGNAL(toggled(bool)), groupBox3, SLOT(setEnabled(bool)));
        QObject::connect(_closeIdle, SIGNAL(toggled(bool)), _idleTime, SLOT(setEnabled(bool)));
        QObject::connect(_launchManager, SIGNAL(toggled(bool)), _autocloseManager, SLOT(setEnabled(bool)));

        tabWidget2->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WalletConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *WalletConfigWidget)
    {
#ifndef UI_QT_NO_WHATSTHIS
        _enabled->setWhatsThis(tr2i18n("<p>The wallet subsystem provides a convenient and secure way to manage all your passwords. This option specifies whether or not you want to use it.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _enabled->setText(tr2i18n("&Enable the KDE wallet subsystem", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        groupBox2->setWhatsThis(tr2i18n("It is best to close your wallets when you are not using them to prevent others from viewing or using them.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        groupBox2->setTitle(tr2i18n("Close Wallet", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        _closeIdle->setWhatsThis(tr2i18n("<p><b>Close wallet after a period of inactivity.</b><br>When a wallet is closed the password is needed to access it again.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _closeIdle->setText(tr2i18n("Close when unused for:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        _idleTime->setWhatsThis(tr2i18n("<p><b>Close wallet after a period of inactivity.</b><br>When a wallet is closed the password is needed to access it again.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _idleTime->setSuffix(tr2i18n(" min", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        _screensaverLock->setWhatsThis(tr2i18n("<p><b>Close wallet as soon as the screensaver starts.</b><br>When a wallet is closed the password is needed to access it again.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _screensaverLock->setText(tr2i18n("Close when screensaver starts", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        _autoclose->setWhatsThis(tr2i18n("<p><b>Close wallet as soon as applications that use it have stopped.</b><br>Note that your wallet will only be closed when all applications that use it have stopped.<br>When a wallet is closed the password is needed to access it again.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _autoclose->setText(tr2i18n("Close when last application stops using it", Q_NULLPTR));
        groupBox4->setTitle(tr2i18n("Automatic Wallet Selection", Q_NULLPTR));
        textLabel1_2->setText(tr2i18n("Select wallet to use as default:", Q_NULLPTR));
        _newWallet->setText(tr2i18n("New...", Q_NULLPTR));
        _localWalletSelected->setText(tr2i18n("Different wallet for local passwords:", Q_NULLPTR));
        _newLocalWallet->setText(tr2i18n("New...", Q_NULLPTR));
        groupBox3->setTitle(tr2i18n("Wallet Manager", Q_NULLPTR));
        _launchManager->setText(tr2i18n("Show manager in system tray", Q_NULLPTR));
        _autocloseManager->setText(tr2i18n("Hide system tray icon when last wallet closes", Q_NULLPTR));
        tabWidget2->setTabText(tabWidget2->indexOf(tab1), tr2i18n("Wallet Preferences", Q_NULLPTR));
        _openPrompt->setText(tr2i18n("&Prompt when an application accesses a wallet", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = _accessList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Policy", Q_NULLPTR));
        ___qtreewidgetitem->setText(1, tr2i18n("Application", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, tr2i18n("Wallet", Q_NULLPTR));
        tabWidget2->setTabText(tabWidget2->indexOf(tab2), tr2i18n("Access Control", Q_NULLPTR));
        _launch->setText(tr2i18n("&Launch Wallet Manager", Q_NULLPTR));
        Q_UNUSED(WalletConfigWidget);
    } // retranslateUi

};

namespace Ui {
    class WalletConfigWidget: public Ui_WalletConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WALLETCONFIGWIDGET_H

