/****************************************************************************
** Meta object code from reading C++ file 'kwalletpopup.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kwalletmanager-17.12.3/src/manager/kwalletpopup.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletpopup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWalletPopup_t {
    QByteArrayData data[14];
    char stringdata0[184];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWalletPopup_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWalletPopup_t qt_meta_stringdata_KWalletPopup = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KWalletPopup"
QT_MOC_LITERAL(1, 13, 12), // "walletOpened"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 10), // "walletName"
QT_MOC_LITERAL(4, 38, 12), // "walletClosed"
QT_MOC_LITERAL(5, 51, 13), // "walletDeleted"
QT_MOC_LITERAL(6, 65, 13), // "walletCreated"
QT_MOC_LITERAL(7, 79, 20), // "walletChangePassword"
QT_MOC_LITERAL(8, 100, 10), // "openWallet"
QT_MOC_LITERAL(9, 111, 12), // "deleteWallet"
QT_MOC_LITERAL(10, 124, 11), // "closeWallet"
QT_MOC_LITERAL(11, 136, 12), // "createWallet"
QT_MOC_LITERAL(12, 149, 20), // "changeWalletPassword"
QT_MOC_LITERAL(13, 170, 13) // "disconnectApp"

    },
    "KWalletPopup\0walletOpened\0\0walletName\0"
    "walletClosed\0walletDeleted\0walletCreated\0"
    "walletChangePassword\0openWallet\0"
    "deleteWallet\0closeWallet\0createWallet\0"
    "changeWalletPassword\0disconnectApp"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWalletPopup[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       5,    1,   75,    2, 0x06 /* Public */,
       6,    0,   78,    2, 0x06 /* Public */,
       7,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   82,    2, 0x0a /* Public */,
       9,    0,   83,    2, 0x0a /* Public */,
      10,    0,   84,    2, 0x0a /* Public */,
      11,    0,   85,    2, 0x0a /* Public */,
      12,    0,   86,    2, 0x0a /* Public */,
      13,    0,   87,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KWalletPopup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KWalletPopup *_t = static_cast<KWalletPopup *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->walletOpened((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->walletClosed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->walletDeleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->walletCreated(); break;
        case 4: _t->walletChangePassword((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->openWallet(); break;
        case 6: _t->deleteWallet(); break;
        case 7: _t->closeWallet(); break;
        case 8: _t->createWallet(); break;
        case 9: _t->changeWalletPassword(); break;
        case 10: _t->disconnectApp(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KWalletPopup::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletPopup::walletOpened)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KWalletPopup::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletPopup::walletClosed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KWalletPopup::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletPopup::walletDeleted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KWalletPopup::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletPopup::walletCreated)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KWalletPopup::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KWalletPopup::walletChangePassword)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KWalletPopup::staticMetaObject = {
    { &QMenu::staticMetaObject, qt_meta_stringdata_KWalletPopup.data,
      qt_meta_data_KWalletPopup,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KWalletPopup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletPopup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWalletPopup.stringdata0))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int KWalletPopup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KWalletPopup::walletOpened(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KWalletPopup::walletClosed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KWalletPopup::walletDeleted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KWalletPopup::walletCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KWalletPopup::walletChangePassword(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
