/****************************************************************************
** Meta object code from reading C++ file 'kwalletmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kwalletmanager-17.12.3/src/manager/kwalletmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWalletManager_t {
    QByteArrayData data[31];
    char stringdata0[407];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWalletManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWalletManager_t qt_meta_stringdata_KWalletManager = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KWalletManager"
QT_MOC_LITERAL(1, 15, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 31, 30), // "org.kde.kwallet.kwalletmanager"
QT_MOC_LITERAL(3, 62, 12), // "createWallet"
QT_MOC_LITERAL(4, 75, 0), // ""
QT_MOC_LITERAL(5, 76, 12), // "deleteWallet"
QT_MOC_LITERAL(6, 89, 11), // "closeWallet"
QT_MOC_LITERAL(7, 101, 10), // "walletName"
QT_MOC_LITERAL(8, 112, 20), // "changeWalletPassword"
QT_MOC_LITERAL(9, 133, 10), // "openWallet"
QT_MOC_LITERAL(10, 144, 14), // "openWalletFile"
QT_MOC_LITERAL(11, 159, 4), // "path"
QT_MOC_LITERAL(12, 164, 11), // "contextMenu"
QT_MOC_LITERAL(13, 176, 3), // "pos"
QT_MOC_LITERAL(14, 180, 13), // "walletCreated"
QT_MOC_LITERAL(15, 194, 16), // "allWalletsClosed"
QT_MOC_LITERAL(16, 211, 19), // "updateWalletDisplay"
QT_MOC_LITERAL(17, 231, 16), // "aWalletWasOpened"
QT_MOC_LITERAL(18, 248, 12), // "shuttingDown"
QT_MOC_LITERAL(19, 261, 12), // "possiblyQuit"
QT_MOC_LITERAL(20, 274, 12), // "editorClosed"
QT_MOC_LITERAL(21, 287, 14), // "KXmlGuiWindow*"
QT_MOC_LITERAL(22, 302, 1), // "e"
QT_MOC_LITERAL(23, 304, 14), // "possiblyRescan"
QT_MOC_LITERAL(24, 319, 3), // "app"
QT_MOC_LITERAL(25, 323, 11), // "setupWallet"
QT_MOC_LITERAL(26, 335, 15), // "closeAllWallets"
QT_MOC_LITERAL(27, 351, 13), // "exportWallets"
QT_MOC_LITERAL(28, 365, 13), // "importWallets"
QT_MOC_LITERAL(29, 379, 18), // "beginConfiguration"
QT_MOC_LITERAL(30, 398, 8) // "configUI"

    },
    "KWalletManager\0D-Bus Interface\0"
    "org.kde.kwallet.kwalletmanager\0"
    "createWallet\0\0deleteWallet\0closeWallet\0"
    "walletName\0changeWalletPassword\0"
    "openWallet\0openWalletFile\0path\0"
    "contextMenu\0pos\0walletCreated\0"
    "allWalletsClosed\0updateWalletDisplay\0"
    "aWalletWasOpened\0shuttingDown\0"
    "possiblyQuit\0editorClosed\0KXmlGuiWindow*\0"
    "e\0possiblyRescan\0app\0setupWallet\0"
    "closeAllWallets\0exportWallets\0"
    "importWallets\0beginConfiguration\0"
    "configUI"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWalletManager[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      22,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    0,  126,    4, 0x0a /* Public */,
       5,    0,  127,    4, 0x0a /* Public */,
       6,    1,  128,    4, 0x0a /* Public */,
       8,    1,  131,    4, 0x0a /* Public */,
       9,    1,  134,    4, 0x0a /* Public */,
      10,    1,  137,    4, 0x0a /* Public */,
      12,    1,  140,    4, 0x0a /* Public */,
      14,    1,  143,    4, 0x0a /* Public */,
      15,    0,  146,    4, 0x4a /* Public | isScriptable */,
      16,    0,  147,    4, 0x4a /* Public | isScriptable */,
      17,    0,  148,    4, 0x4a /* Public | isScriptable */,
      18,    0,  149,    4, 0x08 /* Private */,
      19,    0,  150,    4, 0x08 /* Private */,
      20,    1,  151,    4, 0x08 /* Private */,
      23,    3,  154,    4, 0x08 /* Private */,
      25,    0,  161,    4, 0x08 /* Private */,
       9,    0,  162,    4, 0x08 /* Private */,
      26,    0,  163,    4, 0x08 /* Private */,
      27,    0,  164,    4, 0x08 /* Private */,
      28,    0,  165,    4, 0x08 /* Private */,
      29,    0,  166,    4, 0x08 /* Private */,
      30,    0,  167,    4, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QPoint,   13,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   24,    4,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KWalletManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KWalletManager *_t = static_cast<KWalletManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->createWallet(); break;
        case 1: _t->deleteWallet(); break;
        case 2: _t->closeWallet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->changeWalletPassword((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->openWallet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->openWalletFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 7: _t->walletCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->allWalletsClosed(); break;
        case 9: _t->updateWalletDisplay(); break;
        case 10: _t->aWalletWasOpened(); break;
        case 11: _t->shuttingDown(); break;
        case 12: _t->possiblyQuit(); break;
        case 13: _t->editorClosed((*reinterpret_cast< KXmlGuiWindow*(*)>(_a[1]))); break;
        case 14: _t->possiblyRescan((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 15: _t->setupWallet(); break;
        case 16: _t->openWallet(); break;
        case 17: _t->closeAllWallets(); break;
        case 18: _t->exportWallets(); break;
        case 19: _t->importWallets(); break;
        case 20: _t->beginConfiguration(); break;
        case 21: _t->configUI(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KXmlGuiWindow* >(); break;
            }
            break;
        }
    }
}

const QMetaObject KWalletManager::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KWalletManager.data,
      qt_meta_data_KWalletManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KWalletManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWalletManager.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KWalletManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
